==> frostwire_5.6.0.orig.tar.gz: frostwire-5.6.0/common/components/core/com/frostwire/search/mininova/MininovaSearchPerformer.java <==
/*
 * Created by Angel Leon (@gubatron), Alden Torres (aldenml)
 * Copyright (c) 2011, 2012, FrostWire(R). All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.frostwire.search.mininova;

import java.util.List;

import com.frostwire.search.torrent.TorrentJsonSearchPerformer;
import com.frostwire.util.JsonUtils;

/**
 * @author gubatron
 * @author aldenml
 *
 */
public class MininovaSearchPerformer extends TorrentJsonSearchPerformer<MininovaVuzeItem, MininovaVuzeSearchResult> {

    public MininovaSearchPerformer(long token, String keywords, int timeout) {
        super(token, keywords, timeout, 1);
    }

    @Override
    protected String getUrl(int page, String encodedKeywords) {
        return "http://www.mininova.org/vuze.php?search=" + encodedKeywords;
    }

    @Override
    protected List<MininovaVuzeItem> parseJson(String json) {
        //fix what seems to be an intentional JSON syntax typo put ther by mininova
        json = json.replace("\"hash\":", ", \"hash\":");
        MininovaVuzeResponse response = JsonUtils.toObject(json, MininovaVuzeResponse.class);
        return response.results;
    }

    @Override
    protected MininovaVuzeSearchResult fromItem(MininovaVuzeItem item) {
        return new MininovaVuzeSearchResult(item);
    }
}

==> frostwire_5.7.0.orig.tar.gz: frostwire-5.7.0/common/components/core/com/frostwire/search/mininova/MininovaSearchPerformer.java <==
/*
 * Created by Angel Leon (@gubatron), Alden Torres (aldenml)
 * Copyright (c) 2011-2014, FrostWire(R). All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.frostwire.search.mininova;

import java.util.List;

import com.frostwire.search.domainalias.DomainAliasManager;
import com.frostwire.search.torrent.TorrentJsonSearchPerformer;
import com.frostwire.util.JsonUtils;

/**
 * @author gubatron
 * @author aldenml
 *
 */
public class MininovaSearchPerformer extends TorrentJsonSearchPerformer<MininovaVuzeItem, MininovaVuzeSearchResult> {

    public MininovaSearchPerformer(DomainAliasManager domainAliasManager, long token, String keywords, int timeout) {
        super(domainAliasManager, token, keywords, timeout, 1);
    }

    @Override
    protected String getUrl(int page, String encodedKeywords) {
        return "http://"+getDomainNameToUse()+"/vuze.php?search=" + encodedKeywords;
    }

    @Override
    protected List<MininovaVuzeItem> parseJson(String json) {
        //fix what seems to be an intentional JSON syntax typo put ther by mininova
        json = json.replace("\"hash\":", ", \"hash\":");
        MininovaVuzeResponse response = JsonUtils.toObject(json, MininovaVuzeResponse.class);
        return response.results;
    }

    @Override
    protected MininovaVuzeSearchResult fromItem(MininovaVuzeItem item) {
        return new MininovaVuzeSearchResult(item);
    }
}
